@@ -85,54 +85,7 @@ class ArrayBase: public ExprBase<Derived>
     ~ArrayBase() {}
 
   public:
-    /** @return safely a constant value of the element (i,j) of the 2D container.
-      *  @param i,j row and column indexes
-      **/
-     inline ConstReturnType operator()(int i, int j) const
-     {
- #ifdef STK_BOUNDS_CHECK
-       if (this->beginRows() > i) { STKOUT_OF_RANGE_2ARG(ITContainerBase::elt, i, j, beginRows() > i);}
-       if (this->endRows() <= i)  { STKOUT_OF_RANGE_2ARG(ITContainerBase::elt, i, j, endRows() <= i);}
-       if (this->beginCols() > j) { STKOUT_OF_RANGE_2ARG(ITContainerBase::elt, i, j, beginCols() > j);}
-       if (this->endCols() <= j)  { STKOUT_OF_RANGE_2ARG(ITContainerBase::elt, i, j, endCols() <= j);}
- #endif
-       return this->elt(i,j);
-     }
-     /** @return reference on the ith element
-      *  @param i index of the ith element
-      **/
-     inline ConstReturnType operator[](int i) const
-     {
-       STK_STATIC_ASSERT_ONE_DIMENSION_ONLY(Derived);
-       return this->elt(i);
-     }
-     /** @return reference on the number */
-     inline ConstReturnType operator()() const { return this->elt();}
-     /** @return value of the element (i,j) of the 2D container.
-      *  @param i,j row and column indexes
-      **/
-     inline Type& operator()(int i, int j)
-     {
- #ifdef STK_BOUNDS_CHECK
-       if (this->beginRows() > i) { STKOUT_OF_RANGE_2ARG(ITContainer::elt, i, j, beginRows() > i);}
-       if (this->endRows() <= i)  { STKOUT_OF_RANGE_2ARG(ITContainer::elt, i, j, endRows() <= i);}
-       if (this->beginCols() > j) { STKOUT_OF_RANGE_2ARG(ITContainer::elt, i, j, beginCols() > j);}
-       if (this->endCols() <= j)  { STKOUT_OF_RANGE_2ARG(ITContainer::elt, i, j, endCols() <= j);}
- #endif
-       return this->asDerived().elt2Impl(i,j);
-     }
-     /** @return reference on the ith element
-      *  @param i index of the ith element
-      **/
-     inline Type& operator[](int i)
-     {
-       STK_STATIC_ASSERT_ONE_DIMENSION_ONLY(Derived);
-       return this->elt(i);
-     }
-     /** @return reference on the number */
-     inline Type& operator()() { return this->elt();}
-
-
+    // start appliers
     /** Apply the Visitor @c visitor to the whole coefficients of the array.
       * The template parameter @c Visitor is the type of the visitor and provides
       * the following interface:
